var _ogre_id_8h =
[
    [ "Ogre::Id", "class_ogre_1_1_id.html", "class_ogre_1_1_id" ],
    [ "Ogre::IdObject", "class_ogre_1_1_id_object.html", "class_ogre_1_1_id_object" ],
    [ "Ogre::IdType", "namespace_ogre.html#afcab9522fbe8edb20b32fbb5d8a48ed5", null ]
];